pub struct PluginMetadata {
pub name: String,
pub version: String,
pub description: String,
pub author: String,
pub category: PluginCategory,
pub supported_types: Vec<TypeId>,
pub dependencies: Vec<String>,
pub capabilities: Vec<PluginCapability>,
pub min_sdk_version: String,
}Expand description
Metadata describing a plugin
This structure contains comprehensive information about a plugin including its identity, capabilities, dependencies, and requirements. It’s used by the plugin system for discovery, validation, and compatibility checking.
Examples
use sklears_core::plugin::{PluginMetadata, PluginCategory, PluginCapability};
use std::any::TypeId;
let metadata = PluginMetadata {
name: "LinearRegression".to_string(),
version: "1.0.0".to_string(),
description: "Linear regression algorithm".to_string(),
author: "SKLears Team".to_string(),
category: PluginCategory::Algorithm,
supported_types: vec![TypeId::of::<f64>()],
dependencies: vec!["ndarray".to_string()],
capabilities: vec![PluginCapability::Parallel],
min_sdk_version: "0.1.0".to_string(),
};Fields
name: StringPlugin name - should be unique within a category
version: StringPlugin version following semantic versioning
description: StringHuman-readable description of the plugin’s functionality
Plugin author or organization
category: PluginCategoryPlugin category for organization and discovery
supported_types: Vec<TypeId>List of supported input data types
dependencies: Vec<String>Required external dependencies
capabilities: Vec<PluginCapability>Plugin capabilities and features
min_sdk_version: StringMinimum SDK version required for this plugin